@@ -27,7 +27,7 @@ class TimeEditArgs(CommonParameterWidgetArgs):
 
 
 class TimeEdit(CommonParameterWidget):
-    HIDE_DEFAULT_WIDGET = True
+    HIDE_DEFAULT_VALUE_WIDGET = True
     SET_DEFAULT_ON_INIT = True
 
     _WidgetArgsClass = TimeEditArgs
